[prev in list] [next in list] [prev in thread] [next in thread] 

List:       pear-cvs
Subject:    [PEAR-CVS] cvs: pear /File_Archive Archive.php
From:       "Charles Brunet" <cbrunet () php ! net>
Date:       2008-05-28 15:57:42
Message-ID: cvscbrunet1211990262 () cvsserver
[Download RAW message or body]

cbrunet		Wed May 28 15:57:42 2008 UTC

  Modified files:              
    /pear/File_Archive	Archive.php 
  Log:
  fixe for 5566
  
http://cvs.php.net/viewvc.cgi/pear/File_Archive/Archive.php?r1=1.88&r2=1.89&diff_format=u
Index: pear/File_Archive/Archive.php
diff -u pear/File_Archive/Archive.php:1.88 pear/File_Archive/Archive.php:1.89
--- pear/File_Archive/Archive.php:1.88	Sun Jan  7 22:39:15 2007
+++ pear/File_Archive/Archive.php	Wed May 28 15:57:42 2008
@@ -27,7 +27,7 @@
  * @author     Vincent Lascaux <vincentlascaux@php.net>
  * @copyright  1997-2005 The PHP Group
  * @license    http://www.gnu.org/copyleft/lesser.html  LGPL
- * @version    CVS: $Id: Archive.php,v 1.88 2007/01/07 22:39:15 pfischer Exp $
+ * @version    CVS: $Id: Archive.php,v 1.89 2008/05/28 15:57:42 cbrunet Exp $
  * @link       http://pear.php.net/package/File_Archive
  */
 
@@ -613,13 +613,14 @@
      *
      * @param string $extension the checked extension
      * @return bool whether this file can be understood reading its extension
      *         Currently, supported extensions are tar, zip, gz, tgz, tbz, bz2,
      *         bzip2, ar, deb
      */
     function isKnownExtension($extension)
     {
         return $extension == 'tar'   ||
                $extension == 'zip'   ||
+               $extension == 'jar'   ||
                $extension == 'gz'    ||
                $extension == 'tgz'   ||
                $extension == 'tbz'   ||
@@ -672,6 +673,7 @@
             return new File_Archive_Reader_Gzip($source, $sourceOpened);
 
         case 'zip':
+        case 'jar':
             require_once 'File/Archive/Reader/Zip.php';
             return new File_Archive_Reader_Zip($source, $sourceOpened);
 
@@ -1428,4 +1430,4 @@
     }
 }
 
-?>
\ No newline at end of file
+?>
@@ -613,13 +613,14 @@
      * @param string $extension the checked extension
      * @return bool whether this file can be understood reading its extension
-     *         Currently, supported extensions are tar, zip, gz, tgz, tbz, bz2,
-     *         bzip2, ar, deb
+     *         Currently, supported extensions are tar, zip, jar, gz, tgz,
+     *         tbz, bz2, bzip2, ar, deb
      */
     function isKnownExtension($extension)



-- 
PEAR CVS Mailing List (http://pear.php.net/)
To unsubscribe, visit: http://www.php.net/unsub.php

[prev in list] [next in list] [prev in thread] [next in thread] 

Configure | About | News | Add a list | Sponsored by KoreLogic